[metacity] theme-parser: Look for themes in XDG_USER_DATA_DIR, not in ~/.themes



commit 52a524ee4a7e14d99451ea3f596b353ddf7957d4
Author: Jasper St. Pierre <jstpierre mecheye net>
Date:   Wed May 2 14:08:39 2012 -0400

    theme-parser: Look for themes in XDG_USER_DATA_DIR, not in ~/.themes
    
    https://bugzilla.gnome.org/show_bug.cgi?id=675316

 src/ui/theme-parser.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/ui/theme-parser.c b/src/ui/theme-parser.c
index 5b641cd..c7684c8 100644
--- a/src/ui/theme-parser.c
+++ b/src/ui/theme-parser.c
@@ -4416,11 +4416,11 @@ meta_theme_load (const char  *theme_name,
   /* We try all supported major versions from current to oldest */
   for (major_version = THEME_MAJOR_VERSION; (major_version > 0); major_version--)
     {
       /* We try first in home dir, XDG_DATA_DIRS, then system dir for themes */
 
-      /* Try home dir for themes */
-      theme_dir = g_build_filename (g_get_home_dir (),
-                                    ".themes",
+      /* Try XDG_USER_DATA_DIR first */
+      theme_dir = g_build_filename (g_get_user_data_dir(),
+                                    "themes",
                                     theme_name,
                                     THEME_SUBDIR,
                                     NULL);
@@ -4416,11 +4416,11 @@ meta_theme_load (const char  *theme_name,
   for (major_version = THEME_MAJOR_VERSION; (major_version > 0); major_version--)
     {
-      /* We try first in home dir, XDG_DATA_DIRS, then system dir for themes */
+      /* We try first in XDG_USER_DATA_DIR, XDG_DATA_DIRS, then system dir for themes */
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]